@@ -2110,3 +2110,206 @@ em_utils_find_message_window (EMailFormatterMode display_mode,
 
 	return NULL;
 }
+
+/**
+ * em_utils_import_pgp_key:
+ * @parent: a #GtkWindow parent for a dialog
+ * @session: (nullable): a #CamelSession
+ * @keydata: key data to import
+ * @keydata_size: size of the @keydata, in bytes
+ * @error: return location for a #GError, or %NULL
+ *
+ * Asks the user whether he/she wants to import the provided OpenPGP key
+ * and tries to import it.
+ *
+ * Returns: whether the import succeeded
+ *
+ * Since: 3.50
+ **/
+gboolean
+em_utils_import_pgp_key (GtkWindow *parent,
+			 CamelSession *session,
+			 const guint8 *keydata,
+			 gsize keydata_size,
+			 GError **error)
+{
+	struct _trust_options {
+		const gchar *label;
+		CamelGpgTrust trust;
+		GtkToggleButton *button;
+	} trust_options[] = {
+		{ NC_("trust", "_Unknown"),	CAMEL_GPG_TRUST_UNKNOWN,	NULL },
+		{ NC_("trust", "_Never"),	CAMEL_GPG_TRUST_NEVER,		NULL },
+		{ NC_("trust", "_Marginal"),	CAMEL_GPG_TRUST_MARGINAL,	NULL },
+		{ NC_("trust", "_Full"),	CAMEL_GPG_TRUST_FULL,		NULL },
+		{ NC_("trust", "_Ultimate"),	CAMEL_GPG_TRUST_ULTIMATE,	NULL }
+	};
+	EAlert *alert;
+	CamelGpgContext *gpgctx;
+	GSList *key_infos = NULL, *link;
+	GtkWidget *dialog;
+	GtkWidget *widget;
+	GtkWidget *container;
+	guint ii;
+	gboolean success = FALSE;
+
+	if (session)
+		g_return_val_if_fail (CAMEL_IS_SESSION (session), FALSE);
+	g_return_val_if_fail (keydata != NULL, FALSE);
+	g_return_val_if_fail (keydata_size > 0, FALSE);
+
+	gpgctx = CAMEL_GPG_CONTEXT (camel_gpg_context_new (session));
+
+	if (!camel_gpg_context_get_key_data_info_sync (gpgctx, keydata, keydata_size, 0, &key_infos, NULL, error)) {
+		g_clear_object (&gpgctx);
+		return FALSE;
+	}
+
+	alert = e_alert_new ("mail:ask-import-pgp-key", NULL);
+	dialog = e_alert_dialog_new (parent, alert);
+	g_object_unref (alert);
+
+	container = e_alert_dialog_get_content_area (E_ALERT_DIALOG (dialog));
+	widget = gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
+	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+	container = widget;
+
+	for (link = key_infos; link; link = g_slist_next (link)) {
+		CamelGpgKeyInfo *nfo = link->data;
+
+		if (nfo && camel_gpg_key_info_get_id (nfo)) {
+			GSList *user_ids;
+			gchar *tmp;
+
+			tmp = g_strdup_printf (_("Key ID: %s"), camel_gpg_key_info_get_id (nfo));
+			widget = gtk_label_new (tmp);
+			g_object_set (widget,
+				"halign", GTK_ALIGN_START,
+				"margin-top", link == key_infos ? 0 : 12,
+				"selectable", TRUE,
+				"xalign", 0.0,
+				NULL);
+			gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+			g_free (tmp);
+
+			tmp = g_strdup_printf (_("Fingerprint: %s"), camel_gpg_key_info_get_fingerprint (nfo));
+			widget = gtk_label_new (tmp);
+			g_object_set (widget,
+				"halign", GTK_ALIGN_START,
+				"margin-start", 12,
+				"selectable", TRUE,
+				"xalign", 0.0,
+				NULL);
+			gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+			g_free (tmp);
+
+			if (camel_gpg_key_info_get_creation_date (nfo) > 0) {
+				gchar *fmt;
+
+				fmt = e_datetime_format_format ("mail", "table", DTFormatKindDateTime, (time_t) camel_gpg_key_info_get_creation_date (nfo));
+				if (fmt) {
+					tmp = g_strdup_printf (_("Created: %s"), fmt);
+					widget = gtk_label_new (tmp);
+					g_object_set (widget,
+						"halign", GTK_ALIGN_START,
+						"margin-start", 12,
+						"selectable", TRUE,
+						"xalign", 0.0,
+						NULL);
+					gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+					g_free (tmp);
+					g_free (fmt);
+				}
+			}
+
+			user_ids = camel_gpg_key_info_get_user_ids (nfo);
+			if (user_ids) {
+				GSList *id_link;
+				GString *ids;
+
+				ids = g_string_new ("");
+
+				for (id_link = user_ids; id_link; id_link = g_slist_next (id_link)) {
+					const gchar *id = id_link->data;
+
+					if (id && *id) {
+						if (ids->len > 0)
+							g_string_append (ids, ", ");
+						g_string_append (ids, id);
+					}
+				}
+
+				if (ids->len > 0) {
+					tmp = g_strdup_printf (_("User ID: %s"), ids->str);
+					widget = gtk_label_new (tmp);
+					g_object_set (widget,
+						"halign", GTK_ALIGN_START,
+						"margin-start", 12,
+						"selectable", TRUE,
+						"max-width-chars", 80,
+						"width-chars", 80,
+						"wrap", TRUE,
+						"wrap-mode", PANGO_WRAP_WORD_CHAR,
+						"xalign", 0.0,
+						NULL);
+					gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+					g_free (tmp);
+				}
+
+				g_string_free (ids, TRUE);
+			}
+		}
+	}
+
+	widget = gtk_label_new (_("Set trust level for the key:"));
+	gtk_widget_set_halign (widget, GTK_ALIGN_START);
+	gtk_widget_set_margin_top (widget, 12);
+	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+
+	for (ii = 0; ii < G_N_ELEMENTS (trust_options); ii++) {
+		widget = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (trust_options[0].button),
+			g_dpgettext2 (GETTEXT_PACKAGE, "trust", trust_options[ii].label));
+		gtk_widget_set_margin_start (widget, 12);
+		gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+
+		trust_options[ii].button = GTK_TOGGLE_BUTTON (widget);
+	}
+
+	/* Preselect the 'full' trust level, thus the key can be used to encrypt messages */
+	g_warn_if_fail (ii > 3);
+	g_warn_if_fail (trust_options[3].trust == CAMEL_GPG_TRUST_FULL);
+	gtk_toggle_button_set_active (trust_options[3].button, TRUE);
+
+	gtk_widget_show_all (container);
+
+	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES) {
+		CamelGpgTrust trust = CAMEL_GPG_TRUST_NONE;
+
+		for (ii = 0; ii < G_N_ELEMENTS (trust_options); ii++) {
+			if (gtk_toggle_button_get_active (trust_options[ii].button)) {
+				trust = trust_options[ii].trust;
+				break;
+			}
+		}
+
+		success = camel_gpg_context_import_key_sync (gpgctx, keydata, keydata_size, 0, NULL, error);
+		if (success) {
+			for (link = key_infos; link && success; link = g_slist_next (link)) {
+				CamelGpgKeyInfo *nfo = link->data;
+
+				if (nfo && camel_gpg_key_info_get_id (nfo)) {
+					success = camel_gpg_context_set_key_trust_sync (gpgctx,
+						camel_gpg_key_info_get_id (nfo), trust, NULL, error);
+				}
+			}
+		}
+	} else {
+		g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_CANCELLED, _("Operation was cancelled"));
+	}
+
+	g_slist_free_full (key_infos, (GDestroyNotify) camel_gpg_key_info_free);
+	gtk_widget_destroy (dialog);
+	g_clear_object (&gpgctx);
+
+	return success;
+}
